"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useMediaQuery = void 0;
var react_1 = require("react");
var defaultBreakpointConfig = {
    sm: 576,
    md: 768,
    lg: 992,
    xl: 1200,
};
var getBreakPoint = function (config) {
    var windowWidth = window.innerWidth;
    if (windowWidth < config.sm) {
        return "xs";
    }
    if (windowWidth < config.md) {
        return "sm";
    }
    if (windowWidth < config.lg) {
        return "md";
    }
    if (windowWidth < config.xl) {
        return "lg";
    }
    return "xl";
};
exports.useMediaQuery = function (config) {
    if (config === void 0) { config = defaultBreakpointConfig; }
    var initialState = getBreakPoint(config);
    var _a = react_1.useState(initialState), state = _a[0], setState = _a[1];
    var onScreen = function () {
        var screens = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            screens[_i] = arguments[_i];
        }
        return screens.includes(state);
    };
    var onResize = function () {
        var breakpoint = getBreakPoint(config);
        setState(breakpoint);
    };
    react_1.useEffect(function () {
        window.addEventListener("resize", onResize);
        return function () { return window.removeEventListener("resize", onResize); };
    }, []);
    return [state, onScreen];
};
exports.default = exports.useMediaQuery;
//# sourceMappingURL=useMediaQuery.js.map